==> landing-page-webflow-scripts-1.5.0.tgz: package/src/anang/anang-events.js <==
import { PUBLIC_URLS } from '../config/public-endpoints';
import { FormatUtils } from '../util/format-utils';

/**
 * returns the entered user input
 * @returns {string} user mail address
 */
const getUserMail = () => {
  const data = $('.demo-input');
  return data[0].value;
};

const getUserMembershipNumber = () => {
  const data = $('.membershipnumber-input');
  return data[0].value;
};

/**
 * posts user input to the backend
 * TODO: verify email with regex!
 */
const postToBookAnangDemo = (mail, memberShipNumber) => {
  $.ajax({
    type: 'POST',
    url: PUBLIC_URLS.sellerBookADemo,
    data: JSON.stringify({
      mail,
      userLandingPageInputValue: {
        memberId: memberShipNumber,
        page: FormatUtils.getCurrentWindowLocation()
      }
    }),
    contentType: 'application/json',
    success: function () {
      $('.success').css({ display: 'block' });
      $('.error').css({ display: 'none' });
    },
    error: function (error) {
      $('.error').css({ display: 'block' });
      $('.success').css({ display: 'none' });
    }
  });
};

const initBookADemoClickListener = () => {
  $('.form.anang').submit(function (e) {
    e.preventDefault();

    const mail = getUserMail();
    const memberShipNumber = getUserMembershipNumber();

    postToBookAnangDemo(mail, memberShipNumber);
  });
};

export const anangEvents = (() => ({
  init: function () {
    // getting webflow javascript
    const webflow = Webflow || [];

    webflow.push(function () {
      $(document).off('submit');

      initBookADemoClickListener();
    });
  }
}))();

==> landing-page-webflow-scripts-1.5.4.tgz: package/src/anang/anang-events.js <==
import { PUBLIC_URLS } from '../config/public-endpoints';
import { FormatUtils } from '../util/format-utils';

/**
 * returns the entered user input
 * @returns {string} user mail address
 */
const getUserMail = () => {
  const data = $('.demo-input');
  return data[0].value;
};

const getUserMembershipNumber = () => {
  const data = $('.membershipnumber-input');
  return data[0].value;
};

/**
 * posts user input to the backend
 * TODO: verify email with regex!
 */
const postToBookAnangDemo = (mail, memberShipNumber) => {
  $.ajax({
    type: 'POST',
    url: PUBLIC_URLS.sellerBookADemo,
    data: JSON.stringify({
      mail,
      userLandingPageInputValue: `page: ${FormatUtils.getCurrentWindowLocation()}, memberId: ${memberShipNumber}`
    }),
    contentType: 'application/json',
    success: function () {
      $('.success').css({ display: 'block' });
      $('.error').css({ display: 'none' });
    },
    error: function (error) {
      $('.error').css({ display: 'block' });
      $('.success').css({ display: 'none' });
    }
  });
};

const initBookADemoClickListener = () => {
  $('.form.anang').submit(function (e) {
    e.preventDefault();

    const mail = getUserMail();
    const memberShipNumber = getUserMembershipNumber();

    postToBookAnangDemo(mail, memberShipNumber);
  });
};

export const anangEvents = (() => ({
  init: function () {
    // getting webflow javascript
    const webflow = Webflow || [];

    webflow.push(function () {
      $(document).off('submit');

      initBookADemoClickListener();
    });
  }
}))();
